# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupPolicySetDefinitionArgs', 'GroupPolicySetDefinition']

@pulumi.input_type
class GroupPolicySetDefinitionArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[_builtins.str],
                 management_group_id: pulumi.Input[_builtins.str],
                 policy_definition_references: pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]],
                 policy_type: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]] = None):
        """
        The set of arguments for constructing a GroupPolicySetDefinition resource.
        :param pulumi.Input[_builtins.str] display_name: The display name of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]] policy_definition_references: One or more `policy_definition_reference` blocks as defined below.
        :param pulumi.Input[_builtins.str] policy_type: The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] description: The description of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] metadata: The metadata for the Policy Set Definition in JSON format.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] parameters: The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]] policy_definition_groups: One or more `policy_definition_group` blocks as defined below.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "management_group_id", management_group_id)
        pulumi.set(__self__, "policy_definition_references", policy_definition_references)
        pulumi.set(__self__, "policy_type", policy_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if policy_definition_groups is not None:
            pulumi.set(__self__, "policy_definition_groups", policy_definition_groups)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The display name of this Policy Set Definition.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "management_group_id")

    @management_group_id.setter
    def management_group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "management_group_id", value)

    @_builtins.property
    @pulumi.getter(name="policyDefinitionReferences")
    def policy_definition_references(self) -> pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]:
        """
        One or more `policy_definition_reference` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_references")

    @policy_definition_references.setter
    def policy_definition_references(self, value: pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]):
        pulumi.set(self, "policy_definition_references", value)

    @_builtins.property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> pulumi.Input[_builtins.str]:
        """
        The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "policy_type")

    @policy_type.setter
    def policy_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "policy_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of this Policy Set Definition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The metadata for the Policy Set Definition in JSON format.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parameters", value)

    @_builtins.property
    @pulumi.getter(name="policyDefinitionGroups")
    def policy_definition_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]]:
        """
        One or more `policy_definition_group` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_groups")

    @policy_definition_groups.setter
    def policy_definition_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]]):
        pulumi.set(self, "policy_definition_groups", value)


@pulumi.input_type
class _GroupPolicySetDefinitionState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]] = None,
                 policy_definition_references: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]] = None,
                 policy_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GroupPolicySetDefinition resources.
        :param pulumi.Input[_builtins.str] description: The description of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] display_name: The display name of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] metadata: The metadata for the Policy Set Definition in JSON format.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] parameters: The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]] policy_definition_groups: One or more `policy_definition_group` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]] policy_definition_references: One or more `policy_definition_reference` blocks as defined below.
        :param pulumi.Input[_builtins.str] policy_type: The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if management_group_id is not None:
            pulumi.set(__self__, "management_group_id", management_group_id)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if policy_definition_groups is not None:
            pulumi.set(__self__, "policy_definition_groups", policy_definition_groups)
        if policy_definition_references is not None:
            pulumi.set(__self__, "policy_definition_references", policy_definition_references)
        if policy_type is not None:
            pulumi.set(__self__, "policy_type", policy_type)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of this Policy Set Definition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of this Policy Set Definition.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "management_group_id")

    @management_group_id.setter
    def management_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "management_group_id", value)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The metadata for the Policy Set Definition in JSON format.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parameters", value)

    @_builtins.property
    @pulumi.getter(name="policyDefinitionGroups")
    def policy_definition_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]]:
        """
        One or more `policy_definition_group` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_groups")

    @policy_definition_groups.setter
    def policy_definition_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]]):
        pulumi.set(self, "policy_definition_groups", value)

    @_builtins.property
    @pulumi.getter(name="policyDefinitionReferences")
    def policy_definition_references(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]]:
        """
        One or more `policy_definition_reference` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_references")

    @policy_definition_references.setter
    def policy_definition_references(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]]):
        pulumi.set(self, "policy_definition_references", value)

    @_builtins.property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "policy_type")

    @policy_type.setter
    def policy_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_type", value)


@pulumi.type_token("azure:management/groupPolicySetDefinition:GroupPolicySetDefinition")
class GroupPolicySetDefinition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]]] = None,
                 policy_definition_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]]] = None,
                 policy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Policy Set Definition for a Management Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.management.Group("example", display_name="Example")
        example_group_policy_set_definition = azure.management.GroupPolicySetDefinition("example",
            name="example",
            policy_type="Custom",
            display_name="Example",
            management_group_id=example.id,
            parameters=\"\"\"   {
               \\"allowedLocations\\": {
                   \\"type\\": \\"Array\\",
                   \\"metadata\\": {
                       \\"description\\": \\"The list of allowed locations for resources.\\",
                       \\"displayName\\": \\"Allowed locations\\",
                       \\"strongType\\": \\"location\\"
                   }
               }
           }
        \"\"\",
            policy_definition_references=[{
                "version": "1.0.*",
                "policy_definition_id": "/providers/Microsoft.Authorization/policyDefinitions/e765b5de-1225-4ba3-bd56-1ac6695af988",
                "parameter_values": \"\"\"   {
             \\"listOfAllowedLocations\\": {\\"value\\": \\"[parameters('allowedLocations')]\\"}
           }
        \"\"\",
            }])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Management` - 2025-01-01

        ## Import

        Policy Set Definitions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:management/groupPolicySetDefinition:GroupPolicySetDefinition example /providers/Microsoft.Management/managementGroups/0000000-0000-0000-0000-000000000000/providers/Microsoft.Authorization/policySetDefinitions/policySetDefinitionName
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] display_name: The display name of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] metadata: The metadata for the Policy Set Definition in JSON format.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] parameters: The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]] policy_definition_groups: One or more `policy_definition_group` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]] policy_definition_references: One or more `policy_definition_reference` blocks as defined below.
        :param pulumi.Input[_builtins.str] policy_type: The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupPolicySetDefinitionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Policy Set Definition for a Management Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.management.Group("example", display_name="Example")
        example_group_policy_set_definition = azure.management.GroupPolicySetDefinition("example",
            name="example",
            policy_type="Custom",
            display_name="Example",
            management_group_id=example.id,
            parameters=\"\"\"   {
               \\"allowedLocations\\": {
                   \\"type\\": \\"Array\\",
                   \\"metadata\\": {
                       \\"description\\": \\"The list of allowed locations for resources.\\",
                       \\"displayName\\": \\"Allowed locations\\",
                       \\"strongType\\": \\"location\\"
                   }
               }
           }
        \"\"\",
            policy_definition_references=[{
                "version": "1.0.*",
                "policy_definition_id": "/providers/Microsoft.Authorization/policyDefinitions/e765b5de-1225-4ba3-bd56-1ac6695af988",
                "parameter_values": \"\"\"   {
             \\"listOfAllowedLocations\\": {\\"value\\": \\"[parameters('allowedLocations')]\\"}
           }
        \"\"\",
            }])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Management` - 2025-01-01

        ## Import

        Policy Set Definitions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:management/groupPolicySetDefinition:GroupPolicySetDefinition example /providers/Microsoft.Management/managementGroups/0000000-0000-0000-0000-000000000000/providers/Microsoft.Authorization/policySetDefinitions/policySetDefinitionName
        ```

        :param str resource_name: The name of the resource.
        :param GroupPolicySetDefinitionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupPolicySetDefinitionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]]] = None,
                 policy_definition_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]]] = None,
                 policy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupPolicySetDefinitionArgs.__new__(GroupPolicySetDefinitionArgs)

            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if management_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'management_group_id'")
            __props__.__dict__["management_group_id"] = management_group_id
            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["name"] = name
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["policy_definition_groups"] = policy_definition_groups
            if policy_definition_references is None and not opts.urn:
                raise TypeError("Missing required property 'policy_definition_references'")
            __props__.__dict__["policy_definition_references"] = policy_definition_references
            if policy_type is None and not opts.urn:
                raise TypeError("Missing required property 'policy_type'")
            __props__.__dict__["policy_type"] = policy_type
        super(GroupPolicySetDefinition, __self__).__init__(
            'azure:management/groupPolicySetDefinition:GroupPolicySetDefinition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            metadata: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parameters: Optional[pulumi.Input[_builtins.str]] = None,
            policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]]] = None,
            policy_definition_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]]] = None,
            policy_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'GroupPolicySetDefinition':
        """
        Get an existing GroupPolicySetDefinition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] display_name: The display name of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] metadata: The metadata for the Policy Set Definition in JSON format.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] parameters: The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]] policy_definition_groups: One or more `policy_definition_group` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]] policy_definition_references: One or more `policy_definition_reference` blocks as defined below.
        :param pulumi.Input[_builtins.str] policy_type: The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupPolicySetDefinitionState.__new__(_GroupPolicySetDefinitionState)

        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["management_group_id"] = management_group_id
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["name"] = name
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["policy_definition_groups"] = policy_definition_groups
        __props__.__dict__["policy_definition_references"] = policy_definition_references
        __props__.__dict__["policy_type"] = policy_type
        return GroupPolicySetDefinition(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of this Policy Set Definition.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of this Policy Set Definition.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "management_group_id")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[_builtins.str]:
        """
        The metadata for the Policy Set Definition in JSON format.
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        """
        return pulumi.get(self, "parameters")

    @_builtins.property
    @pulumi.getter(name="policyDefinitionGroups")
    def policy_definition_groups(self) -> pulumi.Output[Optional[Sequence['outputs.GroupPolicySetDefinitionPolicyDefinitionGroup']]]:
        """
        One or more `policy_definition_group` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_groups")

    @_builtins.property
    @pulumi.getter(name="policyDefinitionReferences")
    def policy_definition_references(self) -> pulumi.Output[Sequence['outputs.GroupPolicySetDefinitionPolicyDefinitionReference']]:
        """
        One or more `policy_definition_reference` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_references")

    @_builtins.property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> pulumi.Output[_builtins.str]:
        """
        The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "policy_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['HyperVReplicationPolicyArgs', 'HyperVReplicationPolicy']

@pulumi.input_type
class HyperVReplicationPolicyArgs:
    def __init__(__self__, *,
                 application_consistent_snapshot_frequency_in_hours: pulumi.Input[_builtins.int],
                 recovery_point_retention_in_hours: pulumi.Input[_builtins.int],
                 recovery_vault_id: pulumi.Input[_builtins.str],
                 replication_interval_in_seconds: pulumi.Input[_builtins.int],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a HyperVReplicationPolicy resource.
        :param pulumi.Input[_builtins.int] application_consistent_snapshot_frequency_in_hours: Specifies the frequency at which to create application consistent recovery points.
        :param pulumi.Input[_builtins.int] recovery_point_retention_in_hours: The duration in hours for which the recovery points need to be stored.
        :param pulumi.Input[_builtins.str] recovery_vault_id: The id of the vault that should be updated. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] replication_interval_in_seconds: Specifies how frequently data should be synchronized between source and target locations. Possible values are `30` and `300`.
        :param pulumi.Input[_builtins.str] name: The name of the replication policy. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "application_consistent_snapshot_frequency_in_hours", application_consistent_snapshot_frequency_in_hours)
        pulumi.set(__self__, "recovery_point_retention_in_hours", recovery_point_retention_in_hours)
        pulumi.set(__self__, "recovery_vault_id", recovery_vault_id)
        pulumi.set(__self__, "replication_interval_in_seconds", replication_interval_in_seconds)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="applicationConsistentSnapshotFrequencyInHours")
    def application_consistent_snapshot_frequency_in_hours(self) -> pulumi.Input[_builtins.int]:
        """
        Specifies the frequency at which to create application consistent recovery points.
        """
        return pulumi.get(self, "application_consistent_snapshot_frequency_in_hours")

    @application_consistent_snapshot_frequency_in_hours.setter
    def application_consistent_snapshot_frequency_in_hours(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "application_consistent_snapshot_frequency_in_hours", value)

    @_builtins.property
    @pulumi.getter(name="recoveryPointRetentionInHours")
    def recovery_point_retention_in_hours(self) -> pulumi.Input[_builtins.int]:
        """
        The duration in hours for which the recovery points need to be stored.
        """
        return pulumi.get(self, "recovery_point_retention_in_hours")

    @recovery_point_retention_in_hours.setter
    def recovery_point_retention_in_hours(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "recovery_point_retention_in_hours", value)

    @_builtins.property
    @pulumi.getter(name="recoveryVaultId")
    def recovery_vault_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the vault that should be updated. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "recovery_vault_id")

    @recovery_vault_id.setter
    def recovery_vault_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "recovery_vault_id", value)

    @_builtins.property
    @pulumi.getter(name="replicationIntervalInSeconds")
    def replication_interval_in_seconds(self) -> pulumi.Input[_builtins.int]:
        """
        Specifies how frequently data should be synchronized between source and target locations. Possible values are `30` and `300`.
        """
        return pulumi.get(self, "replication_interval_in_seconds")

    @replication_interval_in_seconds.setter
    def replication_interval_in_seconds(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "replication_interval_in_seconds", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the replication policy. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _HyperVReplicationPolicyState:
    def __init__(__self__, *,
                 application_consistent_snapshot_frequency_in_hours: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 recovery_point_retention_in_hours: Optional[pulumi.Input[_builtins.int]] = None,
                 recovery_vault_id: Optional[pulumi.Input[_builtins.str]] = None,
                 replication_interval_in_seconds: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering HyperVReplicationPolicy resources.
        :param pulumi.Input[_builtins.int] application_consistent_snapshot_frequency_in_hours: Specifies the frequency at which to create application consistent recovery points.
        :param pulumi.Input[_builtins.str] name: The name of the replication policy. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] recovery_point_retention_in_hours: The duration in hours for which the recovery points need to be stored.
        :param pulumi.Input[_builtins.str] recovery_vault_id: The id of the vault that should be updated. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] replication_interval_in_seconds: Specifies how frequently data should be synchronized between source and target locations. Possible values are `30` and `300`.
        """
        if application_consistent_snapshot_frequency_in_hours is not None:
            pulumi.set(__self__, "application_consistent_snapshot_frequency_in_hours", application_consistent_snapshot_frequency_in_hours)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if recovery_point_retention_in_hours is not None:
            pulumi.set(__self__, "recovery_point_retention_in_hours", recovery_point_retention_in_hours)
        if recovery_vault_id is not None:
            pulumi.set(__self__, "recovery_vault_id", recovery_vault_id)
        if replication_interval_in_seconds is not None:
            pulumi.set(__self__, "replication_interval_in_seconds", replication_interval_in_seconds)

    @_builtins.property
    @pulumi.getter(name="applicationConsistentSnapshotFrequencyInHours")
    def application_consistent_snapshot_frequency_in_hours(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the frequency at which to create application consistent recovery points.
        """
        return pulumi.get(self, "application_consistent_snapshot_frequency_in_hours")

    @application_consistent_snapshot_frequency_in_hours.setter
    def application_consistent_snapshot_frequency_in_hours(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "application_consistent_snapshot_frequency_in_hours", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the replication policy. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="recoveryPointRetentionInHours")
    def recovery_point_retention_in_hours(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The duration in hours for which the recovery points need to be stored.
        """
        return pulumi.get(self, "recovery_point_retention_in_hours")

    @recovery_point_retention_in_hours.setter
    def recovery_point_retention_in_hours(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "recovery_point_retention_in_hours", value)

    @_builtins.property
    @pulumi.getter(name="recoveryVaultId")
    def recovery_vault_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the vault that should be updated. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "recovery_vault_id")

    @recovery_vault_id.setter
    def recovery_vault_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "recovery_vault_id", value)

    @_builtins.property
    @pulumi.getter(name="replicationIntervalInSeconds")
    def replication_interval_in_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies how frequently data should be synchronized between source and target locations. Possible values are `30` and `300`.
        """
        return pulumi.get(self, "replication_interval_in_seconds")

    @replication_interval_in_seconds.setter
    def replication_interval_in_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "replication_interval_in_seconds", value)


@pulumi.type_token("azure:siterecovery/hyperVReplicationPolicy:HyperVReplicationPolicy")
class HyperVReplicationPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_consistent_snapshot_frequency_in_hours: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 recovery_point_retention_in_hours: Optional[pulumi.Input[_builtins.int]] = None,
                 recovery_vault_id: Optional[pulumi.Input[_builtins.str]] = None,
                 replication_interval_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Manages a Azure Site Recovery replication policy for HyperV within a Recovery Vault. Replication policies define the frequency at which recovery points are created and how long they are stored.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-rg",
            location="East US")
        vault = azure.recoveryservices.Vault("vault",
            name="example-recovery-vault",
            location=example.location,
            resource_group_name=example.name,
            sku="Standard")
        policy = azure.siterecovery.HyperVReplicationPolicy("policy",
            name="policy",
            recovery_vault_id=vault.id,
            recovery_point_retention_in_hours=2,
            application_consistent_snapshot_frequency_in_hours=1,
            replication_interval_in_seconds=300)
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.RecoveryServices` - 2024-04-01

        ## Import

        Site Recovery Replication Policies can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:siterecovery/hyperVReplicationPolicy:HyperVReplicationPolicy mypolicy /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resource-group-name/providers/Microsoft.RecoveryServices/vaults/recovery-vault-name/replicationPolicies/policy-name
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] application_consistent_snapshot_frequency_in_hours: Specifies the frequency at which to create application consistent recovery points.
        :param pulumi.Input[_builtins.str] name: The name of the replication policy. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] recovery_point_retention_in_hours: The duration in hours for which the recovery points need to be stored.
        :param pulumi.Input[_builtins.str] recovery_vault_id: The id of the vault that should be updated. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] replication_interval_in_seconds: Specifies how frequently data should be synchronized between source and target locations. Possible values are `30` and `300`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HyperVReplicationPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Azure Site Recovery replication policy for HyperV within a Recovery Vault. Replication policies define the frequency at which recovery points are created and how long they are stored.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-rg",
            location="East US")
        vault = azure.recoveryservices.Vault("vault",
            name="example-recovery-vault",
            location=example.location,
            resource_group_name=example.name,
            sku="Standard")
        policy = azure.siterecovery.HyperVReplicationPolicy("policy",
            name="policy",
            recovery_vault_id=vault.id,
            recovery_point_retention_in_hours=2,
            application_consistent_snapshot_frequency_in_hours=1,
            replication_interval_in_seconds=300)
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.RecoveryServices` - 2024-04-01

        ## Import

        Site Recovery Replication Policies can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:siterecovery/hyperVReplicationPolicy:HyperVReplicationPolicy mypolicy /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resource-group-name/providers/Microsoft.RecoveryServices/vaults/recovery-vault-name/replicationPolicies/policy-name
        ```

        :param str resource_name: The name of the resource.
        :param HyperVReplicationPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HyperVReplicationPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_consistent_snapshot_frequency_in_hours: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 recovery_point_retention_in_hours: Optional[pulumi.Input[_builtins.int]] = None,
                 recovery_vault_id: Optional[pulumi.Input[_builtins.str]] = None,
                 replication_interval_in_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HyperVReplicationPolicyArgs.__new__(HyperVReplicationPolicyArgs)

            if application_consistent_snapshot_frequency_in_hours is None and not opts.urn:
                raise TypeError("Missing required property 'application_consistent_snapshot_frequency_in_hours'")
            __props__.__dict__["application_consistent_snapshot_frequency_in_hours"] = application_consistent_snapshot_frequency_in_hours
            __props__.__dict__["name"] = name
            if recovery_point_retention_in_hours is None and not opts.urn:
                raise TypeError("Missing required property 'recovery_point_retention_in_hours'")
            __props__.__dict__["recovery_point_retention_in_hours"] = recovery_point_retention_in_hours
            if recovery_vault_id is None and not opts.urn:
                raise TypeError("Missing required property 'recovery_vault_id'")
            __props__.__dict__["recovery_vault_id"] = recovery_vault_id
            if replication_interval_in_seconds is None and not opts.urn:
                raise TypeError("Missing required property 'replication_interval_in_seconds'")
            __props__.__dict__["replication_interval_in_seconds"] = replication_interval_in_seconds
        super(HyperVReplicationPolicy, __self__).__init__(
            'azure:siterecovery/hyperVReplicationPolicy:HyperVReplicationPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_consistent_snapshot_frequency_in_hours: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            recovery_point_retention_in_hours: Optional[pulumi.Input[_builtins.int]] = None,
            recovery_vault_id: Optional[pulumi.Input[_builtins.str]] = None,
            replication_interval_in_seconds: Optional[pulumi.Input[_builtins.int]] = None) -> 'HyperVReplicationPolicy':
        """
        Get an existing HyperVReplicationPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] application_consistent_snapshot_frequency_in_hours: Specifies the frequency at which to create application consistent recovery points.
        :param pulumi.Input[_builtins.str] name: The name of the replication policy. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] recovery_point_retention_in_hours: The duration in hours for which the recovery points need to be stored.
        :param pulumi.Input[_builtins.str] recovery_vault_id: The id of the vault that should be updated. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] replication_interval_in_seconds: Specifies how frequently data should be synchronized between source and target locations. Possible values are `30` and `300`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HyperVReplicationPolicyState.__new__(_HyperVReplicationPolicyState)

        __props__.__dict__["application_consistent_snapshot_frequency_in_hours"] = application_consistent_snapshot_frequency_in_hours
        __props__.__dict__["name"] = name
        __props__.__dict__["recovery_point_retention_in_hours"] = recovery_point_retention_in_hours
        __props__.__dict__["recovery_vault_id"] = recovery_vault_id
        __props__.__dict__["replication_interval_in_seconds"] = replication_interval_in_seconds
        return HyperVReplicationPolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="applicationConsistentSnapshotFrequencyInHours")
    def application_consistent_snapshot_frequency_in_hours(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies the frequency at which to create application consistent recovery points.
        """
        return pulumi.get(self, "application_consistent_snapshot_frequency_in_hours")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the replication policy. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="recoveryPointRetentionInHours")
    def recovery_point_retention_in_hours(self) -> pulumi.Output[_builtins.int]:
        """
        The duration in hours for which the recovery points need to be stored.
        """
        return pulumi.get(self, "recovery_point_retention_in_hours")

    @_builtins.property
    @pulumi.getter(name="recoveryVaultId")
    def recovery_vault_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the vault that should be updated. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "recovery_vault_id")

    @_builtins.property
    @pulumi.getter(name="replicationIntervalInSeconds")
    def replication_interval_in_seconds(self) -> pulumi.Output[_builtins.int]:
        """
        Specifies how frequently data should be synchronized between source and target locations. Possible values are `30` and `300`.
        """
        return pulumi.get(self, "replication_interval_in_seconds")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ManagedRedisArgs', 'ManagedRedis']

@pulumi.input_type
class ManagedRedisArgs:
    def __init__(__self__, *,
                 resource_group_name: pulumi.Input[_builtins.str],
                 sku_name: pulumi.Input[_builtins.str],
                 customer_managed_key: Optional[pulumi.Input['ManagedRedisCustomerManagedKeyArgs']] = None,
                 default_database: Optional[pulumi.Input['ManagedRedisDefaultDatabaseArgs']] = None,
                 high_availability_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identity: Optional[pulumi.Input['ManagedRedisIdentityArgs']] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 public_network_access: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a ManagedRedis resource.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where the Managed Redis instance should exist. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] sku_name: The features and specification of the Managed Redis instance to deploy. Refer to [the documentation](https://learn.microsoft.com/rest/api/redis/redisenterprisecache/redis-enterprise/create?view=rest-redis-redisenterprisecache-2025-04-01&tabs=HTTP#skuname) for valid values. `Balanced_B3` SKU or higher is required for geo-replication. Changing this forces a new Managed Redis instance to be created.
               
               > **Note:** `Enterprise_` and `EnterpriseFlash_` prefixed SKUs were previously used by Redis Enterprise, and [not supported by Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).
        :param pulumi.Input['ManagedRedisCustomerManagedKeyArgs'] customer_managed_key: A `customer_managed_key` block as defined below.
        :param pulumi.Input['ManagedRedisDefaultDatabaseArgs'] default_database: A `default_database` block as defined below. A Managed Redis instance will not be functional without a database. This block is intentionally optional to allow removal and re-creation of the database for troubleshooting purposes. A default database can be created or deleted in-place, however most properties will trigger an entire cluster replacement if changed.
        :param pulumi.Input[_builtins.bool] high_availability_enabled: Whether to enable high availability for the Managed Redis instance. Defaults to `true`. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input['ManagedRedisIdentityArgs'] identity: An `identity` block as defined below.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the Managed Redis instance should exist. Refer to "Redis Cache" on the [product availability documentation](https://azure.microsoft.com/explore/global-infrastructure/products-by-region/table) for supported locations. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Managed Redis instance. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] public_network_access: The public network access setting for the Managed Redis instance. Possible values are `Enabled` and `Disabled`. Defaults to `Enabled`.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the Managed Redis instance.
        """
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "sku_name", sku_name)
        if customer_managed_key is not None:
            pulumi.set(__self__, "customer_managed_key", customer_managed_key)
        if default_database is not None:
            pulumi.set(__self__, "default_database", default_database)
        if high_availability_enabled is not None:
            pulumi.set(__self__, "high_availability_enabled", high_availability_enabled)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if public_network_access is not None:
            pulumi.set(__self__, "public_network_access", public_network_access)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Resource Group where the Managed Redis instance should exist. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> pulumi.Input[_builtins.str]:
        """
        The features and specification of the Managed Redis instance to deploy. Refer to [the documentation](https://learn.microsoft.com/rest/api/redis/redisenterprisecache/redis-enterprise/create?view=rest-redis-redisenterprisecache-2025-04-01&tabs=HTTP#skuname) for valid values. `Balanced_B3` SKU or higher is required for geo-replication. Changing this forces a new Managed Redis instance to be created.

        > **Note:** `Enterprise_` and `EnterpriseFlash_` prefixed SKUs were previously used by Redis Enterprise, and [not supported by Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).
        """
        return pulumi.get(self, "sku_name")

    @sku_name.setter
    def sku_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "sku_name", value)

    @_builtins.property
    @pulumi.getter(name="customerManagedKey")
    def customer_managed_key(self) -> Optional[pulumi.Input['ManagedRedisCustomerManagedKeyArgs']]:
        """
        A `customer_managed_key` block as defined below.
        """
        return pulumi.get(self, "customer_managed_key")

    @customer_managed_key.setter
    def customer_managed_key(self, value: Optional[pulumi.Input['ManagedRedisCustomerManagedKeyArgs']]):
        pulumi.set(self, "customer_managed_key", value)

    @_builtins.property
    @pulumi.getter(name="defaultDatabase")
    def default_database(self) -> Optional[pulumi.Input['ManagedRedisDefaultDatabaseArgs']]:
        """
        A `default_database` block as defined below. A Managed Redis instance will not be functional without a database. This block is intentionally optional to allow removal and re-creation of the database for troubleshooting purposes. A default database can be created or deleted in-place, however most properties will trigger an entire cluster replacement if changed.
        """
        return pulumi.get(self, "default_database")

    @default_database.setter
    def default_database(self, value: Optional[pulumi.Input['ManagedRedisDefaultDatabaseArgs']]):
        pulumi.set(self, "default_database", value)

    @_builtins.property
    @pulumi.getter(name="highAvailabilityEnabled")
    def high_availability_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable high availability for the Managed Redis instance. Defaults to `true`. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "high_availability_enabled")

    @high_availability_enabled.setter
    def high_availability_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "high_availability_enabled", value)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['ManagedRedisIdentityArgs']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['ManagedRedisIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Azure Region where the Managed Redis instance should exist. Refer to "Redis Cache" on the [product availability documentation](https://azure.microsoft.com/explore/global-infrastructure/products-by-region/table) for supported locations. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Managed Redis instance. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="publicNetworkAccess")
    def public_network_access(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public network access setting for the Managed Redis instance. Possible values are `Enabled` and `Disabled`. Defaults to `Enabled`.
        """
        return pulumi.get(self, "public_network_access")

    @public_network_access.setter
    def public_network_access(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "public_network_access", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the Managed Redis instance.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ManagedRedisState:
    def __init__(__self__, *,
                 customer_managed_key: Optional[pulumi.Input['ManagedRedisCustomerManagedKeyArgs']] = None,
                 default_database: Optional[pulumi.Input['ManagedRedisDefaultDatabaseArgs']] = None,
                 high_availability_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 identity: Optional[pulumi.Input['ManagedRedisIdentityArgs']] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 public_network_access: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sku_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering ManagedRedis resources.
        :param pulumi.Input['ManagedRedisCustomerManagedKeyArgs'] customer_managed_key: A `customer_managed_key` block as defined below.
        :param pulumi.Input['ManagedRedisDefaultDatabaseArgs'] default_database: A `default_database` block as defined below. A Managed Redis instance will not be functional without a database. This block is intentionally optional to allow removal and re-creation of the database for troubleshooting purposes. A default database can be created or deleted in-place, however most properties will trigger an entire cluster replacement if changed.
        :param pulumi.Input[_builtins.bool] high_availability_enabled: Whether to enable high availability for the Managed Redis instance. Defaults to `true`. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] hostname: DNS name of the cluster endpoint.
        :param pulumi.Input['ManagedRedisIdentityArgs'] identity: An `identity` block as defined below.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the Managed Redis instance should exist. Refer to "Redis Cache" on the [product availability documentation](https://azure.microsoft.com/explore/global-infrastructure/products-by-region/table) for supported locations. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Managed Redis instance. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] public_network_access: The public network access setting for the Managed Redis instance. Possible values are `Enabled` and `Disabled`. Defaults to `Enabled`.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where the Managed Redis instance should exist. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] sku_name: The features and specification of the Managed Redis instance to deploy. Refer to [the documentation](https://learn.microsoft.com/rest/api/redis/redisenterprisecache/redis-enterprise/create?view=rest-redis-redisenterprisecache-2025-04-01&tabs=HTTP#skuname) for valid values. `Balanced_B3` SKU or higher is required for geo-replication. Changing this forces a new Managed Redis instance to be created.
               
               > **Note:** `Enterprise_` and `EnterpriseFlash_` prefixed SKUs were previously used by Redis Enterprise, and [not supported by Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the Managed Redis instance.
        """
        if customer_managed_key is not None:
            pulumi.set(__self__, "customer_managed_key", customer_managed_key)
        if default_database is not None:
            pulumi.set(__self__, "default_database", default_database)
        if high_availability_enabled is not None:
            pulumi.set(__self__, "high_availability_enabled", high_availability_enabled)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if public_network_access is not None:
            pulumi.set(__self__, "public_network_access", public_network_access)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if sku_name is not None:
            pulumi.set(__self__, "sku_name", sku_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="customerManagedKey")
    def customer_managed_key(self) -> Optional[pulumi.Input['ManagedRedisCustomerManagedKeyArgs']]:
        """
        A `customer_managed_key` block as defined below.
        """
        return pulumi.get(self, "customer_managed_key")

    @customer_managed_key.setter
    def customer_managed_key(self, value: Optional[pulumi.Input['ManagedRedisCustomerManagedKeyArgs']]):
        pulumi.set(self, "customer_managed_key", value)

    @_builtins.property
    @pulumi.getter(name="defaultDatabase")
    def default_database(self) -> Optional[pulumi.Input['ManagedRedisDefaultDatabaseArgs']]:
        """
        A `default_database` block as defined below. A Managed Redis instance will not be functional without a database. This block is intentionally optional to allow removal and re-creation of the database for troubleshooting purposes. A default database can be created or deleted in-place, however most properties will trigger an entire cluster replacement if changed.
        """
        return pulumi.get(self, "default_database")

    @default_database.setter
    def default_database(self, value: Optional[pulumi.Input['ManagedRedisDefaultDatabaseArgs']]):
        pulumi.set(self, "default_database", value)

    @_builtins.property
    @pulumi.getter(name="highAvailabilityEnabled")
    def high_availability_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable high availability for the Managed Redis instance. Defaults to `true`. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "high_availability_enabled")

    @high_availability_enabled.setter
    def high_availability_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "high_availability_enabled", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DNS name of the cluster endpoint.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['ManagedRedisIdentityArgs']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['ManagedRedisIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Azure Region where the Managed Redis instance should exist. Refer to "Redis Cache" on the [product availability documentation](https://azure.microsoft.com/explore/global-infrastructure/products-by-region/table) for supported locations. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Managed Redis instance. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="publicNetworkAccess")
    def public_network_access(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public network access setting for the Managed Redis instance. Possible values are `Enabled` and `Disabled`. Defaults to `Enabled`.
        """
        return pulumi.get(self, "public_network_access")

    @public_network_access.setter
    def public_network_access(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "public_network_access", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Resource Group where the Managed Redis instance should exist. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The features and specification of the Managed Redis instance to deploy. Refer to [the documentation](https://learn.microsoft.com/rest/api/redis/redisenterprisecache/redis-enterprise/create?view=rest-redis-redisenterprisecache-2025-04-01&tabs=HTTP#skuname) for valid values. `Balanced_B3` SKU or higher is required for geo-replication. Changing this forces a new Managed Redis instance to be created.

        > **Note:** `Enterprise_` and `EnterpriseFlash_` prefixed SKUs were previously used by Redis Enterprise, and [not supported by Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).
        """
        return pulumi.get(self, "sku_name")

    @sku_name.setter
    def sku_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sku_name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the Managed Redis instance.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("azure:managedredis/managedRedis:ManagedRedis")
class ManagedRedis(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer_managed_key: Optional[pulumi.Input[Union['ManagedRedisCustomerManagedKeyArgs', 'ManagedRedisCustomerManagedKeyArgsDict']]] = None,
                 default_database: Optional[pulumi.Input[Union['ManagedRedisDefaultDatabaseArgs', 'ManagedRedisDefaultDatabaseArgsDict']]] = None,
                 high_availability_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identity: Optional[pulumi.Input[Union['ManagedRedisIdentityArgs', 'ManagedRedisIdentityArgsDict']]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 public_network_access: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sku_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages a [Managed Redis](https://learn.microsoft.com/azure/redis/overview). This resource supersedes redis.EnterpriseCluster and redis.EnterpriseDatabase resources. Please refer to the migration guide for more information on migrating from Redis Enterprise to Managed Redis: [Migrating from Redis Enterprise to Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_managed_redis = azure.managedredis.ManagedRedis("example",
            name="example-managed-redis",
            resource_group_name=example.name,
            location=example.location,
            sku_name="Balanced_B3",
            default_database={
                "geo_replication_group_name": "myGeoGroup",
            })
        ```

        ### With Customer Managed Key

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_user_assigned_identity = azure.authorization.UserAssignedIdentity("example",
            name="example",
            resource_group_name=example.name,
            location=example.location)
        example_key_vault = azure.keyvault.KeyVault("example",
            name="example",
            location=example.location,
            resource_group_name=example.name,
            tenant_id=current.tenant_id,
            sku_name="standard",
            purge_protection_enabled=True,
            access_policies=[
                {
                    "tenant_id": current.tenant_id,
                    "object_id": current.object_id,
                    "key_permissions": [
                        "Create",
                        "Delete",
                        "Get",
                        "List",
                        "Purge",
                        "Recover",
                        "Update",
                        "GetRotationPolicy",
                        "SetRotationPolicy",
                    ],
                },
                {
                    "tenant_id": current.tenant_id,
                    "object_id": example_user_assigned_identity.principal_id,
                    "key_permissions": [
                        "Get",
                        "WrapKey",
                        "UnwrapKey",
                    ],
                },
            ])
        example_key = azure.keyvault.Key("example",
            name="managedrediscmk",
            key_vault_id=example_key_vault.id,
            key_type="RSA",
            key_size=2048,
            key_opts=[
                "unwrapKey",
                "wrapKey",
            ])
        example_managed_redis = azure.managedredis.ManagedRedis("example",
            name="example-managed-redis",
            resource_group_name=example.name,
            location=example.location,
            sku_name="Balanced_B3",
            identity={
                "type": "UserAssigned",
                "identity_ids": [example_user_assigned_identity.id],
            },
            customer_managed_key={
                "key_vault_key_id": example_key.id,
                "user_assigned_identity_id": example_user_assigned_identity.id,
            },
            default_database={
                "geo_replication_group_name": "myGeoGroup",
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Cache` - 2025-07-01

        ## Import

        Managed Redis instances can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:managedredis/managedRedis:ManagedRedis example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Cache/redisEnterprise/cluster1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ManagedRedisCustomerManagedKeyArgs', 'ManagedRedisCustomerManagedKeyArgsDict']] customer_managed_key: A `customer_managed_key` block as defined below.
        :param pulumi.Input[Union['ManagedRedisDefaultDatabaseArgs', 'ManagedRedisDefaultDatabaseArgsDict']] default_database: A `default_database` block as defined below. A Managed Redis instance will not be functional without a database. This block is intentionally optional to allow removal and re-creation of the database for troubleshooting purposes. A default database can be created or deleted in-place, however most properties will trigger an entire cluster replacement if changed.
        :param pulumi.Input[_builtins.bool] high_availability_enabled: Whether to enable high availability for the Managed Redis instance. Defaults to `true`. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[Union['ManagedRedisIdentityArgs', 'ManagedRedisIdentityArgsDict']] identity: An `identity` block as defined below.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the Managed Redis instance should exist. Refer to "Redis Cache" on the [product availability documentation](https://azure.microsoft.com/explore/global-infrastructure/products-by-region/table) for supported locations. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Managed Redis instance. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] public_network_access: The public network access setting for the Managed Redis instance. Possible values are `Enabled` and `Disabled`. Defaults to `Enabled`.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where the Managed Redis instance should exist. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] sku_name: The features and specification of the Managed Redis instance to deploy. Refer to [the documentation](https://learn.microsoft.com/rest/api/redis/redisenterprisecache/redis-enterprise/create?view=rest-redis-redisenterprisecache-2025-04-01&tabs=HTTP#skuname) for valid values. `Balanced_B3` SKU or higher is required for geo-replication. Changing this forces a new Managed Redis instance to be created.
               
               > **Note:** `Enterprise_` and `EnterpriseFlash_` prefixed SKUs were previously used by Redis Enterprise, and [not supported by Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the Managed Redis instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ManagedRedisArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a [Managed Redis](https://learn.microsoft.com/azure/redis/overview). This resource supersedes redis.EnterpriseCluster and redis.EnterpriseDatabase resources. Please refer to the migration guide for more information on migrating from Redis Enterprise to Managed Redis: [Migrating from Redis Enterprise to Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_managed_redis = azure.managedredis.ManagedRedis("example",
            name="example-managed-redis",
            resource_group_name=example.name,
            location=example.location,
            sku_name="Balanced_B3",
            default_database={
                "geo_replication_group_name": "myGeoGroup",
            })
        ```

        ### With Customer Managed Key

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_user_assigned_identity = azure.authorization.UserAssignedIdentity("example",
            name="example",
            resource_group_name=example.name,
            location=example.location)
        example_key_vault = azure.keyvault.KeyVault("example",
            name="example",
            location=example.location,
            resource_group_name=example.name,
            tenant_id=current.tenant_id,
            sku_name="standard",
            purge_protection_enabled=True,
            access_policies=[
                {
                    "tenant_id": current.tenant_id,
                    "object_id": current.object_id,
                    "key_permissions": [
                        "Create",
                        "Delete",
                        "Get",
                        "List",
                        "Purge",
                        "Recover",
                        "Update",
                        "GetRotationPolicy",
                        "SetRotationPolicy",
                    ],
                },
                {
                    "tenant_id": current.tenant_id,
                    "object_id": example_user_assigned_identity.principal_id,
                    "key_permissions": [
                        "Get",
                        "WrapKey",
                        "UnwrapKey",
                    ],
                },
            ])
        example_key = azure.keyvault.Key("example",
            name="managedrediscmk",
            key_vault_id=example_key_vault.id,
            key_type="RSA",
            key_size=2048,
            key_opts=[
                "unwrapKey",
                "wrapKey",
            ])
        example_managed_redis = azure.managedredis.ManagedRedis("example",
            name="example-managed-redis",
            resource_group_name=example.name,
            location=example.location,
            sku_name="Balanced_B3",
            identity={
                "type": "UserAssigned",
                "identity_ids": [example_user_assigned_identity.id],
            },
            customer_managed_key={
                "key_vault_key_id": example_key.id,
                "user_assigned_identity_id": example_user_assigned_identity.id,
            },
            default_database={
                "geo_replication_group_name": "myGeoGroup",
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Cache` - 2025-07-01

        ## Import

        Managed Redis instances can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:managedredis/managedRedis:ManagedRedis example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Cache/redisEnterprise/cluster1
        ```

        :param str resource_name: The name of the resource.
        :param ManagedRedisArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ManagedRedisArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer_managed_key: Optional[pulumi.Input[Union['ManagedRedisCustomerManagedKeyArgs', 'ManagedRedisCustomerManagedKeyArgsDict']]] = None,
                 default_database: Optional[pulumi.Input[Union['ManagedRedisDefaultDatabaseArgs', 'ManagedRedisDefaultDatabaseArgsDict']]] = None,
                 high_availability_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identity: Optional[pulumi.Input[Union['ManagedRedisIdentityArgs', 'ManagedRedisIdentityArgsDict']]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 public_network_access: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sku_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ManagedRedisArgs.__new__(ManagedRedisArgs)

            __props__.__dict__["customer_managed_key"] = customer_managed_key
            __props__.__dict__["default_database"] = default_database
            __props__.__dict__["high_availability_enabled"] = high_availability_enabled
            __props__.__dict__["identity"] = identity
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            __props__.__dict__["public_network_access"] = public_network_access
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if sku_name is None and not opts.urn:
                raise TypeError("Missing required property 'sku_name'")
            __props__.__dict__["sku_name"] = sku_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["hostname"] = None
        super(ManagedRedis, __self__).__init__(
            'azure:managedredis/managedRedis:ManagedRedis',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            customer_managed_key: Optional[pulumi.Input[Union['ManagedRedisCustomerManagedKeyArgs', 'ManagedRedisCustomerManagedKeyArgsDict']]] = None,
            default_database: Optional[pulumi.Input[Union['ManagedRedisDefaultDatabaseArgs', 'ManagedRedisDefaultDatabaseArgsDict']]] = None,
            high_availability_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            hostname: Optional[pulumi.Input[_builtins.str]] = None,
            identity: Optional[pulumi.Input[Union['ManagedRedisIdentityArgs', 'ManagedRedisIdentityArgsDict']]] = None,
            location: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            public_network_access: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            sku_name: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None) -> 'ManagedRedis':
        """
        Get an existing ManagedRedis resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ManagedRedisCustomerManagedKeyArgs', 'ManagedRedisCustomerManagedKeyArgsDict']] customer_managed_key: A `customer_managed_key` block as defined below.
        :param pulumi.Input[Union['ManagedRedisDefaultDatabaseArgs', 'ManagedRedisDefaultDatabaseArgsDict']] default_database: A `default_database` block as defined below. A Managed Redis instance will not be functional without a database. This block is intentionally optional to allow removal and re-creation of the database for troubleshooting purposes. A default database can be created or deleted in-place, however most properties will trigger an entire cluster replacement if changed.
        :param pulumi.Input[_builtins.bool] high_availability_enabled: Whether to enable high availability for the Managed Redis instance. Defaults to `true`. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] hostname: DNS name of the cluster endpoint.
        :param pulumi.Input[Union['ManagedRedisIdentityArgs', 'ManagedRedisIdentityArgsDict']] identity: An `identity` block as defined below.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the Managed Redis instance should exist. Refer to "Redis Cache" on the [product availability documentation](https://azure.microsoft.com/explore/global-infrastructure/products-by-region/table) for supported locations. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Managed Redis instance. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] public_network_access: The public network access setting for the Managed Redis instance. Possible values are `Enabled` and `Disabled`. Defaults to `Enabled`.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where the Managed Redis instance should exist. Changing this forces a new Managed Redis instance to be created.
        :param pulumi.Input[_builtins.str] sku_name: The features and specification of the Managed Redis instance to deploy. Refer to [the documentation](https://learn.microsoft.com/rest/api/redis/redisenterprisecache/redis-enterprise/create?view=rest-redis-redisenterprisecache-2025-04-01&tabs=HTTP#skuname) for valid values. `Balanced_B3` SKU or higher is required for geo-replication. Changing this forces a new Managed Redis instance to be created.
               
               > **Note:** `Enterprise_` and `EnterpriseFlash_` prefixed SKUs were previously used by Redis Enterprise, and [not supported by Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the Managed Redis instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ManagedRedisState.__new__(_ManagedRedisState)

        __props__.__dict__["customer_managed_key"] = customer_managed_key
        __props__.__dict__["default_database"] = default_database
        __props__.__dict__["high_availability_enabled"] = high_availability_enabled
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["identity"] = identity
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["public_network_access"] = public_network_access
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["sku_name"] = sku_name
        __props__.__dict__["tags"] = tags
        return ManagedRedis(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="customerManagedKey")
    def customer_managed_key(self) -> pulumi.Output[Optional['outputs.ManagedRedisCustomerManagedKey']]:
        """
        A `customer_managed_key` block as defined below.
        """
        return pulumi.get(self, "customer_managed_key")

    @_builtins.property
    @pulumi.getter(name="defaultDatabase")
    def default_database(self) -> pulumi.Output[Optional['outputs.ManagedRedisDefaultDatabase']]:
        """
        A `default_database` block as defined below. A Managed Redis instance will not be functional without a database. This block is intentionally optional to allow removal and re-creation of the database for troubleshooting purposes. A default database can be created or deleted in-place, however most properties will trigger an entire cluster replacement if changed.
        """
        return pulumi.get(self, "default_database")

    @_builtins.property
    @pulumi.getter(name="highAvailabilityEnabled")
    def high_availability_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to enable high availability for the Managed Redis instance. Defaults to `true`. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "high_availability_enabled")

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[_builtins.str]:
        """
        DNS name of the cluster endpoint.
        """
        return pulumi.get(self, "hostname")

    @_builtins.property
    @pulumi.getter
    def identity(self) -> pulumi.Output[Optional['outputs.ManagedRedisIdentity']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @_builtins.property
    @pulumi.getter
    def location(self) -> pulumi.Output[_builtins.str]:
        """
        The Azure Region where the Managed Redis instance should exist. Refer to "Redis Cache" on the [product availability documentation](https://azure.microsoft.com/explore/global-infrastructure/products-by-region/table) for supported locations. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name which should be used for this Managed Redis instance. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="publicNetworkAccess")
    def public_network_access(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The public network access setting for the Managed Redis instance. Possible values are `Enabled` and `Disabled`. Defaults to `Enabled`.
        """
        return pulumi.get(self, "public_network_access")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Resource Group where the Managed Redis instance should exist. Changing this forces a new Managed Redis instance to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> pulumi.Output[_builtins.str]:
        """
        The features and specification of the Managed Redis instance to deploy. Refer to [the documentation](https://learn.microsoft.com/rest/api/redis/redisenterprisecache/redis-enterprise/create?view=rest-redis-redisenterprisecache-2025-04-01&tabs=HTTP#skuname) for valid values. `Balanced_B3` SKU or higher is required for geo-replication. Changing this forces a new Managed Redis instance to be created.

        > **Note:** `Enterprise_` and `EnterpriseFlash_` prefixed SKUs were previously used by Redis Enterprise, and [not supported by Managed Redis](https://learn.microsoft.com/azure/redis/migrate/migrate-overview).
        """
        return pulumi.get(self, "sku_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A mapping of tags which should be assigned to the Managed Redis instance.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetProjectResult',
    'AwaitableGetProjectResult',
    'get_project',
    'get_project_output',
]

@pulumi.output_type
class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, id=None, location=None, name=None, resource_group_name=None, service_name=None, source_platform=None, tags=None, target_platform=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if source_platform and not isinstance(source_platform, str):
            raise TypeError("Expected argument 'source_platform' to be a str")
        pulumi.set(__self__, "source_platform", source_platform)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if target_platform and not isinstance(target_platform, str):
            raise TypeError("Expected argument 'target_platform' to be a str")
        pulumi.set(__self__, "target_platform", target_platform)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        Azure location where the resource exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> _builtins.str:
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter(name="sourcePlatform")
    def source_platform(self) -> _builtins.str:
        """
        The platform type of the migration source.
        """
        return pulumi.get(self, "source_platform")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        """
        A mapping of tags to assigned to the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="targetPlatform")
    def target_platform(self) -> _builtins.str:
        """
        The platform type of the migration target.
        """
        return pulumi.get(self, "target_platform")


class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            id=self.id,
            location=self.location,
            name=self.name,
            resource_group_name=self.resource_group_name,
            service_name=self.service_name,
            source_platform=self.source_platform,
            tags=self.tags,
            target_platform=self.target_platform)


def get_project(name: Optional[_builtins.str] = None,
                resource_group_name: Optional[_builtins.str] = None,
                service_name: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectResult:
    """
    Use this data source to access information about an existing Database Migration Project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.databasemigration.get_project(name="example-dbms-project",
        resource_group_name="example-rg",
        service_name="example-dbms")
    pulumi.export("name", example.name)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.DataMigration` - 2021-06-30


    :param _builtins.str name: Name of the database migration project.
    :param _builtins.str resource_group_name: Name of the resource group where resource belongs to.
    :param _builtins.str service_name: Name of the database migration service where resource belongs to.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:databasemigration/getProject:getProject', __args__, opts=opts, typ=GetProjectResult).value

    return AwaitableGetProjectResult(
        id=pulumi.get(__ret__, 'id'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        service_name=pulumi.get(__ret__, 'service_name'),
        source_platform=pulumi.get(__ret__, 'source_platform'),
        tags=pulumi.get(__ret__, 'tags'),
        target_platform=pulumi.get(__ret__, 'target_platform'))
def get_project_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                       resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                       service_name: Optional[pulumi.Input[_builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectResult]:
    """
    Use this data source to access information about an existing Database Migration Project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.databasemigration.get_project(name="example-dbms-project",
        resource_group_name="example-rg",
        service_name="example-dbms")
    pulumi.export("name", example.name)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.DataMigration` - 2021-06-30


    :param _builtins.str name: Name of the database migration project.
    :param _builtins.str resource_group_name: Name of the resource group where resource belongs to.
    :param _builtins.str service_name: Name of the database migration service where resource belongs to.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:databasemigration/getProject:getProject', __args__, opts=opts, typ=GetProjectResult)
    return __ret__.apply(lambda __response__: GetProjectResult(
        id=pulumi.get(__response__, 'id'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        service_name=pulumi.get(__response__, 'service_name'),
        source_platform=pulumi.get(__response__, 'source_platform'),
        tags=pulumi.get(__response__, 'tags'),
        target_platform=pulumi.get(__response__, 'target_platform')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetManagedDisksResult',
    'AwaitableGetManagedDisksResult',
    'get_managed_disks',
    'get_managed_disks_output',
]

@pulumi.output_type
class GetManagedDisksResult:
    """
    A collection of values returned by getManagedDisks.
    """
    def __init__(__self__, disks=None, id=None, resource_group_name=None):
        if disks and not isinstance(disks, list):
            raise TypeError("Expected argument 'disks' to be a list")
        pulumi.set(__self__, "disks", disks)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)

    @_builtins.property
    @pulumi.getter
    def disks(self) -> Sequence['outputs.GetManagedDisksDiskResult']:
        """
        a `disk` block as detailed below.
        """
        return pulumi.get(self, "disks")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> _builtins.str:
        return pulumi.get(self, "resource_group_name")


class AwaitableGetManagedDisksResult(GetManagedDisksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetManagedDisksResult(
            disks=self.disks,
            id=self.id,
            resource_group_name=self.resource_group_name)


def get_managed_disks(resource_group_name: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetManagedDisksResult:
    """
    Use this data source to access information about an existing Managed Disk.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    existing = azure.compute.get_managed_disks(resource_group_name="example-resources")
    pulumi.export("firstDiskId", existing_azurerm_managed_disk["disk"][0]["id"])
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Compute` - 2023-04-02


    :param _builtins.str resource_group_name: Specifies the name of the Resource Group where this Managed Disk exists.
    """
    __args__ = dict()
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:compute/getManagedDisks:getManagedDisks', __args__, opts=opts, typ=GetManagedDisksResult).value

    return AwaitableGetManagedDisksResult(
        disks=pulumi.get(__ret__, 'disks'),
        id=pulumi.get(__ret__, 'id'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'))
def get_managed_disks_output(resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetManagedDisksResult]:
    """
    Use this data source to access information about an existing Managed Disk.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    existing = azure.compute.get_managed_disks(resource_group_name="example-resources")
    pulumi.export("firstDiskId", existing_azurerm_managed_disk["disk"][0]["id"])
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Compute` - 2023-04-02


    :param _builtins.str resource_group_name: Specifies the name of the Resource Group where this Managed Disk exists.
    """
    __args__ = dict()
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:compute/getManagedDisks:getManagedDisks', __args__, opts=opts, typ=GetManagedDisksResult)
    return __ret__.apply(lambda __response__: GetManagedDisksResult(
        disks=pulumi.get(__response__, 'disks'),
        id=pulumi.get(__response__, 'id'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAutonomousDatabaseBackupResult',
    'AwaitableGetAutonomousDatabaseBackupResult',
    'get_autonomous_database_backup',
    'get_autonomous_database_backup_output',
]

@pulumi.output_type
class GetAutonomousDatabaseBackupResult:
    """
    A collection of values returned by getAutonomousDatabaseBackup.
    """
    def __init__(__self__, automatic=None, autonomous_database_backup_ocid=None, autonomous_database_id=None, autonomous_database_ocid=None, database_backup_size_in_tbs=None, database_version=None, display_name=None, id=None, lifecycle_details=None, lifecycle_state=None, location=None, name=None, provisioning_state=None, restorable=None, retention_period_in_days=None, time_available_til=None, time_ended=None, time_started=None, type=None):
        if automatic and not isinstance(automatic, bool):
            raise TypeError("Expected argument 'automatic' to be a bool")
        pulumi.set(__self__, "automatic", automatic)
        if autonomous_database_backup_ocid and not isinstance(autonomous_database_backup_ocid, str):
            raise TypeError("Expected argument 'autonomous_database_backup_ocid' to be a str")
        pulumi.set(__self__, "autonomous_database_backup_ocid", autonomous_database_backup_ocid)
        if autonomous_database_id and not isinstance(autonomous_database_id, str):
            raise TypeError("Expected argument 'autonomous_database_id' to be a str")
        pulumi.set(__self__, "autonomous_database_id", autonomous_database_id)
        if autonomous_database_ocid and not isinstance(autonomous_database_ocid, str):
            raise TypeError("Expected argument 'autonomous_database_ocid' to be a str")
        pulumi.set(__self__, "autonomous_database_ocid", autonomous_database_ocid)
        if database_backup_size_in_tbs and not isinstance(database_backup_size_in_tbs, float):
            raise TypeError("Expected argument 'database_backup_size_in_tbs' to be a float")
        pulumi.set(__self__, "database_backup_size_in_tbs", database_backup_size_in_tbs)
        if database_version and not isinstance(database_version, str):
            raise TypeError("Expected argument 'database_version' to be a str")
        pulumi.set(__self__, "database_version", database_version)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if lifecycle_state and not isinstance(lifecycle_state, str):
            raise TypeError("Expected argument 'lifecycle_state' to be a str")
        pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provisioning_state and not isinstance(provisioning_state, str):
            raise TypeError("Expected argument 'provisioning_state' to be a str")
        pulumi.set(__self__, "provisioning_state", provisioning_state)
        if restorable and not isinstance(restorable, bool):
            raise TypeError("Expected argument 'restorable' to be a bool")
        pulumi.set(__self__, "restorable", restorable)
        if retention_period_in_days and not isinstance(retention_period_in_days, int):
            raise TypeError("Expected argument 'retention_period_in_days' to be a int")
        pulumi.set(__self__, "retention_period_in_days", retention_period_in_days)
        if time_available_til and not isinstance(time_available_til, str):
            raise TypeError("Expected argument 'time_available_til' to be a str")
        pulumi.set(__self__, "time_available_til", time_available_til)
        if time_ended and not isinstance(time_ended, str):
            raise TypeError("Expected argument 'time_ended' to be a str")
        pulumi.set(__self__, "time_ended", time_ended)
        if time_started and not isinstance(time_started, str):
            raise TypeError("Expected argument 'time_started' to be a str")
        pulumi.set(__self__, "time_started", time_started)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def automatic(self) -> _builtins.bool:
        return pulumi.get(self, "automatic")

    @_builtins.property
    @pulumi.getter(name="autonomousDatabaseBackupOcid")
    def autonomous_database_backup_ocid(self) -> _builtins.str:
        """
        The backup OCID.
        """
        return pulumi.get(self, "autonomous_database_backup_ocid")

    @_builtins.property
    @pulumi.getter(name="autonomousDatabaseId")
    def autonomous_database_id(self) -> _builtins.str:
        return pulumi.get(self, "autonomous_database_id")

    @_builtins.property
    @pulumi.getter(name="autonomousDatabaseOcid")
    def autonomous_database_ocid(self) -> _builtins.str:
        """
        The OCID of the Autonomous Database OCID.
        """
        return pulumi.get(self, "autonomous_database_ocid")

    @_builtins.property
    @pulumi.getter(name="databaseBackupSizeInTbs")
    def database_backup_size_in_tbs(self) -> _builtins.float:
        return pulumi.get(self, "database_backup_size_in_tbs")

    @_builtins.property
    @pulumi.getter(name="databaseVersion")
    def database_version(self) -> _builtins.str:
        return pulumi.get(self, "database_version")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        The user-friendly name of the backup.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the Autonomous Database Backup.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> _builtins.str:
        """
        Information about the current lifecycle state of the backup.
        """
        return pulumi.get(self, "lifecycle_details")

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> _builtins.str:
        """
        The current state of the backup.
        """
        return pulumi.get(self, "lifecycle_state")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        `- The Azure Region where the Autonomous Database Backup exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="provisioningState")
    def provisioning_state(self) -> _builtins.str:
        """
        The current provisioning state of the Autonomous Database Backup.
        """
        return pulumi.get(self, "provisioning_state")

    @_builtins.property
    @pulumi.getter
    def restorable(self) -> _builtins.bool:
        return pulumi.get(self, "restorable")

    @_builtins.property
    @pulumi.getter(name="retentionPeriodInDays")
    def retention_period_in_days(self) -> _builtins.int:
        """
        The retention period in days for the Autonomous Database Backup.
        """
        return pulumi.get(self, "retention_period_in_days")

    @_builtins.property
    @pulumi.getter(name="timeAvailableTil")
    def time_available_til(self) -> _builtins.str:
        """
        The date and time the backup will become unusable.
        """
        return pulumi.get(self, "time_available_til")

    @_builtins.property
    @pulumi.getter(name="timeEnded")
    def time_ended(self) -> _builtins.str:
        """
        The date and time the backup was completed.
        """
        return pulumi.get(self, "time_ended")

    @_builtins.property
    @pulumi.getter(name="timeStarted")
    def time_started(self) -> _builtins.str:
        """
        The date and time the backup started.
        """
        return pulumi.get(self, "time_started")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        return pulumi.get(self, "type")


class AwaitableGetAutonomousDatabaseBackupResult(GetAutonomousDatabaseBackupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAutonomousDatabaseBackupResult(
            automatic=self.automatic,
            autonomous_database_backup_ocid=self.autonomous_database_backup_ocid,
            autonomous_database_id=self.autonomous_database_id,
            autonomous_database_ocid=self.autonomous_database_ocid,
            database_backup_size_in_tbs=self.database_backup_size_in_tbs,
            database_version=self.database_version,
            display_name=self.display_name,
            id=self.id,
            lifecycle_details=self.lifecycle_details,
            lifecycle_state=self.lifecycle_state,
            location=self.location,
            name=self.name,
            provisioning_state=self.provisioning_state,
            restorable=self.restorable,
            retention_period_in_days=self.retention_period_in_days,
            time_available_til=self.time_available_til,
            time_ended=self.time_ended,
            time_started=self.time_started,
            type=self.type)


def get_autonomous_database_backup(autonomous_database_id: Optional[_builtins.str] = None,
                                   name: Optional[_builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAutonomousDatabaseBackupResult:
    """
    Use this data source to access information about existing Autonomous Database Backups.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_autonomous_database_backup(autonomous_database_id=example_azurerm_oracle_autonomous_database["id"])
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Oracle.Database` - 2025-09-01


    :param _builtins.str autonomous_database_id: The azureId of the Autonomous Database for we will be listing the backups.
    """
    __args__ = dict()
    __args__['autonomousDatabaseId'] = autonomous_database_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:oracle/getAutonomousDatabaseBackup:getAutonomousDatabaseBackup', __args__, opts=opts, typ=GetAutonomousDatabaseBackupResult).value

    return AwaitableGetAutonomousDatabaseBackupResult(
        automatic=pulumi.get(__ret__, 'automatic'),
        autonomous_database_backup_ocid=pulumi.get(__ret__, 'autonomous_database_backup_ocid'),
        autonomous_database_id=pulumi.get(__ret__, 'autonomous_database_id'),
        autonomous_database_ocid=pulumi.get(__ret__, 'autonomous_database_ocid'),
        database_backup_size_in_tbs=pulumi.get(__ret__, 'database_backup_size_in_tbs'),
        database_version=pulumi.get(__ret__, 'database_version'),
        display_name=pulumi.get(__ret__, 'display_name'),
        id=pulumi.get(__ret__, 'id'),
        lifecycle_details=pulumi.get(__ret__, 'lifecycle_details'),
        lifecycle_state=pulumi.get(__ret__, 'lifecycle_state'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        provisioning_state=pulumi.get(__ret__, 'provisioning_state'),
        restorable=pulumi.get(__ret__, 'restorable'),
        retention_period_in_days=pulumi.get(__ret__, 'retention_period_in_days'),
        time_available_til=pulumi.get(__ret__, 'time_available_til'),
        time_ended=pulumi.get(__ret__, 'time_ended'),
        time_started=pulumi.get(__ret__, 'time_started'),
        type=pulumi.get(__ret__, 'type'))
def get_autonomous_database_backup_output(autonomous_database_id: Optional[pulumi.Input[_builtins.str]] = None,
                                          name: Optional[pulumi.Input[_builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAutonomousDatabaseBackupResult]:
    """
    Use this data source to access information about existing Autonomous Database Backups.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_autonomous_database_backup(autonomous_database_id=example_azurerm_oracle_autonomous_database["id"])
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Oracle.Database` - 2025-09-01


    :param _builtins.str autonomous_database_id: The azureId of the Autonomous Database for we will be listing the backups.
    """
    __args__ = dict()
    __args__['autonomousDatabaseId'] = autonomous_database_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:oracle/getAutonomousDatabaseBackup:getAutonomousDatabaseBackup', __args__, opts=opts, typ=GetAutonomousDatabaseBackupResult)
    return __ret__.apply(lambda __response__: GetAutonomousDatabaseBackupResult(
        automatic=pulumi.get(__response__, 'automatic'),
        autonomous_database_backup_ocid=pulumi.get(__response__, 'autonomous_database_backup_ocid'),
        autonomous_database_id=pulumi.get(__response__, 'autonomous_database_id'),
        autonomous_database_ocid=pulumi.get(__response__, 'autonomous_database_ocid'),
        database_backup_size_in_tbs=pulumi.get(__response__, 'database_backup_size_in_tbs'),
        database_version=pulumi.get(__response__, 'database_version'),
        display_name=pulumi.get(__response__, 'display_name'),
        id=pulumi.get(__response__, 'id'),
        lifecycle_details=pulumi.get(__response__, 'lifecycle_details'),
        lifecycle_state=pulumi.get(__response__, 'lifecycle_state'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        provisioning_state=pulumi.get(__response__, 'provisioning_state'),
        restorable=pulumi.get(__response__, 'restorable'),
        retention_period_in_days=pulumi.get(__response__, 'retention_period_in_days'),
        time_available_til=pulumi.get(__response__, 'time_available_til'),
        time_ended=pulumi.get(__response__, 'time_ended'),
        time_started=pulumi.get(__response__, 'time_started'),
        type=pulumi.get(__response__, 'type')))
